@@ -4,7 +4,7 @@ set -a
 
 cd $(dirname $0)
 
-PLUGINNAME=jenkinsv1
+PLUGINNAME=jenkins
 
 CONFDIR="."
 while true ; do
